The Simmate Website
--------------------

This module hosts everything for the website framework/interface. The folder/file structure of this module is the most rigid because it follows the Django opinionated format. The key thing that is moved/missing is the database ORM, which is instead located in the simmate.database module.
